@@ -3,7 +3,7 @@ package PXR::NS;
 use strict;
 use warnings;
 
-our $VERSION = '0.1';
+our $VERSION = '0.1.1';
 
 use constant {
 	XMLNS_STREAM => 'http://etherx.jabber.org/streams',
@@ -64,3 +64,58 @@ push @{$EXPORT_TAGS{'all'}},
 	grep {!$seen{$_}++} @{$EXPORT_TAGS{$_}} foreach keys %EXPORT_TAGS;
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+PXR::NS - Namespace support for PXR, JABBER(tm)
+
+=head1 SYNOPSIS
+
+use PXR::NS qw/ :SERVICE :JABBER :IQ /;
+
+=head1 DESCRIPTION
+
+PXR::NS provides namespace constants for use within PXR::Nodes (or any other
+representation) that requires namespace matching. The following export tags
+are explained below:
+
+=over 4
+
+=item :SERVICE
+
+":SERVICE" tag will import constants for use within the PXR Service environment
+such as the XML namespace jabber:service and its relatives.
+
+=item :JABBER
+
+":JABBER" tag will import various useful constants for use within a normal 
+Jabber client and component(to reference implementation server) situation.
+
+=item ":IQ"
+
+":IQ" tag imports convenience <iq/> packet types such as set, get, result, and
+error
+
+=item ":all"
+
+":all" will import every tag available within the package.
+
+=back
+
+Please reference the source file to know which namespaces are explictly
+supported and exported.
+
+=head1 BUGS
+
+XMPP support needs to thought about.
+
+=head1 AUTHOR
+
+Copyright (c) 2003 Nicholas Perez. Released and distributed under the GPL.
+
+=cut
+
